@@ -20,11 +20,11 @@ around BUILDARGS => sub {
 
     my $args = $class->$orig(@_);
     my $oauth_urls = delete $args->{oauth_urls} || {
-        request_token_url  => "http://twitter.com/oauth/request_token",
-        authentication_url => "http://twitter.com/oauth/authenticate",
-        authorization_url  => "http://twitter.com/oauth/authorize",
-        access_token_url   => "http://twitter.com/oauth/access_token",
-        xauth_url          => "https://twitter.com/oauth/access_token",
+        request_token_url  => "http://api.twitter.com/oauth/request_token",
+        authentication_url => "http://api.twitter.com/oauth/authenticate",
+        authorization_url  => "http://api.twitter.com/oauth/authorize",
+        access_token_url   => "http://api.twitter.com/oauth/access_token",
+        xauth_url          => "https://api.twitter.com/oauth/access_token",
     };
 
     return { %$oauth_urls, %$args };
@@ -203,7 +203,7 @@ override _authenticated_request => sub {
         croak "unexpected http_method: $http_method";
     }
 
-    return $self->ua->request($msg);
+    return $self->_send_request($msg);
 };
 
 sub xauth {
